==> lxqt-runner_2.1.2.orig.tar.xz: lxqt-runner-2.1.2/translations/lxqt-runner_lg.ts <==
<?xml version="1.0" encoding="utf-8"?>
<!DOCTYPE TS>
<TS version="2.1" language="lg">
<context>
    <name>ConfigureDialog</name>
    <message>
        <location filename="../configuredialog/configuredialog.ui" line="14"/>
        <source>Runner Settings</source>
        <translation>Enteekateeka za LXQt-runner</translation>
    </message>
    <message>
        <location filename="../configuredialog/configuredialog.ui" line="20"/>
        <source>Appearance</source>
        <translation>Endabika</translation>
    </message>
    <message>
        <location filename="../configuredialog/configuredialog.ui" line="26"/>
        <source>Positioning:</source>
        <translation>W&apos;erabikira:</translation>
    </message>
    <message>
        <location filename="../configuredialog/configuredialog.ui" line="36"/>
        <source>Top margin</source>
        <translation>Akabanga k&apos;elekawo waggulu</translation>
    </message>
    <message>
        <location filename="../configuredialog/configuredialog.ui" line="43"/>
        <source> px</source>
        <translation> px</translation>
    </message>
    <message>
        <location filename="../configuredialog/configuredialog.ui" line="50"/>
        <source>Show on:</source>
        <translation>Olutimbe kw&apos;erabikira:</translation>
    </message>
    <message>
        <location filename="../configuredialog/configuredialog.ui" line="60"/>
        <source>Show history first</source>
        <translation>Ebyasemba okutandikibwa bye biba bisookanga ku lukalala</translation>
    </message>
    <message>
        <location filename="../configuredialog/configuredialog.ui" line="67"/>
        <source>Store/show history</source>
        <translation>Ebeere n&apos;olukalala lwa byeyasemba okutandika</translation>
    </message>
    <message>
        <location filename="../configuredialog/configuredialog.ui" line="74"/>
        <source>&lt;b&gt;Note&lt;/b&gt;: The size of top-level widgets are constrained to 2/3 of the desktop&apos;s height and width.</source>
        <translation>&lt;b&gt;Genderera&lt;/b&gt;: Olukalala luno lusibidwa butasukka 2/3 eby&apos;obuwanvu n&apos;obugazi bw&apos;olutimbe.</translation>
    </message>
    <message>
        <location filename="../configuredialog/configuredialog.ui" line="77"/>
        <source>Show list with:</source>
        <translation>Bungi bw&apos;ebirabikira ku lukalala:</translation>
    </message>
    <message>
        <location filename="../configuredialog/configuredialog.ui" line="84"/>
        <source> item(s)</source>
        <translation> (ebintu)</translation>
    </message>
    <message>
        <location filename="../configuredialog/configuredialog.ui" line="94"/>
        <source>Clear input on launching</source>
        <translation>Etandikenga w&apos;owandikira wereere</translation>
    </message>
    <message>
        <location filename="../configuredialog/configuredialog.ui" line="111"/>
        <source>Shortcut:</source>
        <translation>Amapeesa agagitandika:</translation>
    </message>
    <message>
        <location filename="../configuredialog/configuredialog.cpp" line="61"/>
        <source>Top edge of the screen</source>
        <translation>Ebeere ku njegoyego ey&apos;olutimbe eya waggulu</translation>
    </message>
    <message>
        <location filename="../configuredialog/configuredialog.cpp" line="62"/>
        <source>Center of the screen</source>
        <translation>Ebeere mu makkati g&apos;olutimbe</translation>
    </message>
    <message>
        <location filename="../configuredialog/configuredialog.cpp" line="67"/>
        <source>Focused screen</source>
        <translation>Ejjenga ku lutimbe olukolerwamu</translation>
    </message>
    <message>
        <location filename="../configuredialog/configuredialog.cpp" line="71"/>
        <source>Always on screen %1</source>
        <translation>Ejjenga ku lutimbe namba %1</translation>
    </message>
    <message>
        <location filename="../configuredialog/configuredialog.cpp" line="80"/>
        <source>Reset</source>
        <translation>Zaawo ebyasooka</translation>
    </message>
</context>
<context>
    <name>Dialog</name>
    <message>
        <location filename="../dialog.ui" line="26"/>
        <source>Application launcher </source>
        <translation>Puloguramu etandika zinnaayo </translation>
    </message>
    <message>
        <location filename="../dialog.cpp" line="106"/>
        <source>Configure</source>
        <translation>Enteekateeka</translation>
    </message>
    <message>
        <location filename="../dialog.cpp" line="110"/>
        <source>Clear History</source>
        <translation>Olukalala lusazemu</translation>
    </message>
    <message>
        <location filename="../dialog.cpp" line="409"/>
        <source>Show/hide runner dialog</source>
        <translation>Laga/kisa akaboozi ka LXQt-runner</translation>
    </message>
</context>
<context>
    <name>QObject</name>
    <message>
        <location filename="../providers.cpp" line="445"/>
        <source>History</source>
        <translation>Ebyatandikibwa</translation>
    </message>
    <message>
        <location filename="../providers.cpp" line="846"/>
        <source>Copy calculation result to clipboard</source>
        <translation>Ebibalidwa bigende awaterekebwa ebikoppedwa</translation>
    </message>
</context>
</TS>

==> lxqt-runner_2.2.0.orig.tar.xz: lxqt-runner-2.2.0/translations/lxqt-runner_lg.ts <==
<?xml version="1.0" encoding="utf-8"?>
<!DOCTYPE TS>
<TS version="2.1" language="lg">
<context>
    <name>ConfigureDialog</name>
    <message>
        <location filename="../configuredialog/configuredialog.ui" line="14"/>
        <source>Runner Settings</source>
        <translation>Enteekateeka za LXQt-runner</translation>
    </message>
    <message>
        <location filename="../configuredialog/configuredialog.ui" line="20"/>
        <source>Appearance</source>
        <translation>Endabika</translation>
    </message>
    <message>
        <location filename="../configuredialog/configuredialog.ui" line="26"/>
        <source>Positioning:</source>
        <translation>W&apos;erabikira:</translation>
    </message>
    <message>
        <location filename="../configuredialog/configuredialog.ui" line="36"/>
        <source>Top margin</source>
        <translation>Akabanga k&apos;elekawo waggulu</translation>
    </message>
    <message>
        <location filename="../configuredialog/configuredialog.ui" line="43"/>
        <source> px</source>
        <translation> px</translation>
    </message>
    <message>
        <location filename="../configuredialog/configuredialog.ui" line="50"/>
        <source>Width:</source>
        <translation>Bugazi:</translation>
    </message>
    <message>
        <location filename="../configuredialog/configuredialog.ui" line="57"/>
        <source>With multiple screens, if the window is shown on the focused screen,
this value is only for the smallest screen. The minimum width is 400 px.</source>
        <translation>Bw&apos;obeera nga kompyuta yo eyungidwako ntimbe ezisukka mu emu,
ennamba eno ekolera mu lusinga obutono. Obugazi obusembayo obutono obusoboka ze px 400.</translation>
    </message>
    <message>
        <location filename="../configuredialog/configuredialog.ui" line="61"/>
        <source>%</source>
        <translation>%</translation>
    </message>
    <message>
        <location filename="../configuredialog/configuredialog.ui" line="71"/>
        <source>Show on:</source>
        <translation>Olutimbe kw&apos;erabikira:</translation>
    </message>
    <message>
        <location filename="../configuredialog/configuredialog.ui" line="108"/>
        <source>Show history first</source>
        <translation>Ebyasemba okutandikibwa bye biba bisookanga ku lukalala</translation>
    </message>
    <message>
        <location filename="../configuredialog/configuredialog.ui" line="101"/>
        <source>Store/show history</source>
        <translation>Ebeere n&apos;olukalala lwa byeyasemba okutandika</translation>
    </message>
    <message>
        <location filename="../configuredialog/configuredialog.ui" line="81"/>
        <source>&lt;b&gt;Note&lt;/b&gt;: The size of top-level widgets are constrained to 2/3 of the desktop&apos;s height and width.</source>
        <translation>&lt;b&gt;Genderera&lt;/b&gt;: Olukalala luno lusibidwa butasukka 2/3 eby&apos;obuwanvu n&apos;obugazi bw&apos;olutimbe.</translation>
    </message>
    <message>
        <location filename="../configuredialog/configuredialog.ui" line="84"/>
        <source>Show list with:</source>
        <translation>Bungi bw&apos;ebirabikira ku lukalala:</translation>
    </message>
    <message>
        <location filename="../configuredialog/configuredialog.ui" line="91"/>
        <source> item(s)</source>
        <translation> (ebintu)</translation>
    </message>
    <message>
        <location filename="../configuredialog/configuredialog.ui" line="115"/>
        <source>Clear input on launching</source>
        <translation>Etandikenga w&apos;owandikira wereere</translation>
    </message>
    <message>
        <location filename="../configuredialog/configuredialog.ui" line="132"/>
        <source>Shortcut:</source>
        <translation>Amapeesa agagitandika:</translation>
    </message>
    <message>
        <location filename="../configuredialog/configuredialog.cpp" line="61"/>
        <source>Top edge of the screen</source>
        <translation>Ebeere ku njegoyego ey&apos;olutimbe eya waggulu</translation>
    </message>
    <message>
        <location filename="../configuredialog/configuredialog.cpp" line="62"/>
        <source>Center of the screen</source>
        <translation>Ebeere mu makkati g&apos;olutimbe</translation>
    </message>
    <message>
        <location filename="../configuredialog/configuredialog.cpp" line="71"/>
        <source>On Wayland, the shortcut has to be added
in the compositor settings for &apos;lxqt-runner&apos;.</source>
        <translation>Mu Wayland ebyanguyisamirimu obitegekera mu nteekateeka za
puloguramu ekwanaganya ebirabikira awakolerwa ezikwata ku &apos;lxqt-runner&apos;.</translation>
    </message>
    <message>
        <location filename="../configuredialog/configuredialog.cpp" line="83"/>
        <source>Focused screen</source>
        <translation>Ejjenga ku lutimbe olukolerwamu</translation>
    </message>
    <message>
        <location filename="../configuredialog/configuredialog.cpp" line="87"/>
        <source>Always on screen %1</source>
        <translation>Ejjenga ku lutimbe namba %1</translation>
    </message>
    <message>
        <location filename="../configuredialog/configuredialog.cpp" line="96"/>
        <source>Reset</source>
        <translation>Zaawo ebyasooka</translation>
    </message>
</context>
<context>
    <name>Dialog</name>
    <message>
        <location filename="../dialog.ui" line="26"/>
        <source>Application launcher </source>
        <translation>Puloguramu etandika zinnaayo </translation>
    </message>
    <message>
        <location filename="../dialog.cpp" line="109"/>
        <source>Configure</source>
        <translation>Enteekateeka</translation>
    </message>
    <message>
        <location filename="../dialog.cpp" line="113"/>
        <source>Clear History</source>
        <translation>Olukalala lusazemu</translation>
    </message>
    <message>
        <location filename="../dialog.cpp" line="515"/>
        <source>Show/hide runner dialog</source>
        <translation>Laga/kisa akaboozi ka LXQt-runner</translation>
    </message>
</context>
<context>
    <name>QObject</name>
    <message>
        <location filename="../providers.cpp" line="445"/>
        <source>History</source>
        <translation>Ebyatandikibwa</translation>
    </message>
    <message>
        <location filename="../providers.cpp" line="846"/>
        <source>Copy calculation result to clipboard</source>
        <translation>Ebibalidwa bigende awaterekebwa ebikoppedwa</translation>
    </message>
</context>
</TS>
